import logging
#from cosmic_sdk.connectors.posthog.models import Group, User, Event
import requests
import sys
import os
#from .models import SlackCredentials, SlackMessage, SlackHistoryRequest, SlackMessageResponse, SlackHistoryResponse
from slack_sdk import WebClient
from slack_sdk.errors import SlackApiError

# Ref: https://tools.slack.dev/python-slack-sdk/api-docs/slack_sdk/
logger = logging.getLogger(__name__)

class SlackService:
    def __init__(self, credentials):
        self.slack_bot_token = credentials.get('slack_bot_token')
        if not self.slack_bot_token:
            print(f"Missing required credential: 'slack_bot_token'")
            print(credentials)
            raise ValueError("Missing required credential: 'slack_bot_token'")
        self.client = WebClient(token=self.slack_bot_token)
        self.channel_id = ""

    def set_channel_id(self, channel_id: str):
        self.channel_id = channel_id

    def get_channel_id(self):
        return self.channel_id


    def get_token(self):
        return self.client.token
    
    
    def send_message(self, message: str):
        try:
            print(f"Channel ID in send_message: {self.channel_id}")
            print(f"Type of channel_id: {type(self.channel_id)}")
            print(f"Message: {message}")
            print(f"Type of message: {type(message)}")
            
            response = self.client.chat_postMessage(
                channel=self.channel_id,
                text=message
            )
            return response
        except SlackApiError as e:
            print(f"Slack API Error: {str(e)}")
            raise ValueError(f"Failed to send message: {str(e)}")
        
    def get_channel_history(self, request):
        try:
            response = self.client.conversations_history(
                channel=request.channel,
                limit=request.limit,
                oldest=request.oldest,
                latest=request.latest,
                inclusive=request.inclusive
            )
            return response
        except SlackApiError as e:
            raise ValueError(f"Failed to get channel history: {str(e)}")
        

    

